@@ -1,3 +1,3 @@
 from .base import Tool
-from . import mirror_wget
+from . import mirror_download
 from . import mirror_reprepro
